/v1/projects/{project_id}/qemu/vms/{vm_id}/suspend — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Qemu »

# /v1/projects/{project_id}/qemu/vms/{vm_id}/suspend

Contents

- /v1/projects/{project_id}/qemu/vms/{vm_id}/suspend
  - POST /v1/projects/{project_id}/qemu/vms/{vm_id}/suspend
    - Parameters
    - Response status codes

## POST /v1/projects/{project_id}/qemu/vms/{vm_id}/suspend

Suspend a Qemu.instance

### Parameters

- vm_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance suspended

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Qemu »